#
# spec file for package gswrap
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           gswrap
Version:        0.1
Release:        11.2
Summary:        The ghostscript container to wrap ghostscript within
License:        LGPL-2.1-or-later
Group:          Productivity/Security
URL:            https://github.com/bitstreamout/ghostscriptwrap
Source0:        gswrap
Requires:       /usr/bin/gs.bin
Requires:       bubblewrap
Requires:       coreutils
Requires:       sed
BuildRequires:  sed
BuildRequires:  update-alternatives
Requires(post): update-alternatives
Requires(preun):update-alternatives
BuildArch:      noarch
%define debug_package %nil

%description
If the option -dSAFER is used with gswrap, this script uses bwrap
from the "bubblewrap" package to embbedd the final ghostscript
command within a minimal container. For this, a new, completely empty
filesystem namespace on a tmpfs is populated with the required
libraries and files to run the ghostscript command.

%prep
%setup -q -c -T

%build
sed -r '/ghostscript=@@GS@@/{s^@@GS@@^/usr/bin/gs.bin^}' < %{S:0} > gs.wrap

%install
install -d %buildroot%{_bindir}
install -d %buildroot%{_sysconfdir}/alternatives
install -m 755 gs.wrap %buildroot%{_bindir}/gs.wrap
ln -sf %{_bindir}/gs.wrap %{buildroot}%{_sysconfdir}/alternatives/gs
ln -sf %{_sysconfdir}/alternatives/gs %{buildroot}%{_bindir}/gs

%post
%{_sbindir}/update-alternatives \
  --install %{_bindir}/gs gs %{_bindir}/gs.wrap 100

%preun
if test $1 -eq 0 ; then
    %{_sbindir}/update-alternatives \
    --remove gs %{_bindir}/gs.wrap
fi

%files
%defattr(-,root,root)
%_bindir/gs.wrap
%_bindir/gs
%ghost %config %{_sysconfdir}/alternatives/gs

%changelog
* Fri Feb  9 2024 Dr. Werner Fink <werner@suse.de>
- Allow also abstract X11 socket
* Thu Sep 14 2023 Dr. Werner Fink <werner@suse.de>
- Make it work even with different hwcaps versions
* Wed Dec  8 2021 Dr. Werner Fink <werner@suse.de>
- Use this version for new package in SLE-12-SP5 (jsc#SLE-21704)
  and SLE-15 (jsc#SLE-21705 and jsc#SLE-21706)
* Fri Nov 19 2021 Dr. Werner Fink <werner@suse.de>
- Fix bugs introduced by last change
  which was ad646933d3b9ec6d767842535414b4af1020c2f7 (boo#1191683)
* Fri Oct 15 2021 Dr. Werner Fink <werner@suse.de>
- Quote all variable which might include space
* Fri Oct 15 2021 Dr. Werner Fink <werner@suse.de>
- Allow spaces in path, file, and user names
  as well as check if all used programs are found.
* Tue Oct 12 2021 Dr. Werner Fink <werner@suse.de>
- Use TERM instead of KILL to let bwrap do its work
- Enable bwrap to execute its option --die-with-parent
* Mon Sep 20 2021 Dr. Werner Fink <werner@suse.de>
- Map -o with its argument to -sOutputFile= (boo#1190614)
* Wed Oct  7 2020 Dr. Werner Fink <werner@suse.de>
- Handle gv and gsview
* Wed May 20 2020 Dr. Werner Fink <werner@suse.de>
- Allow option files as well
* Fri Jan 10 2020 Dr. Werner Fink <werner@suse.de>
- Handle relative paths more gracefully
* Fri Jan 10 2020 Dr. Werner Fink <werner@suse.de>
- Allow %%stdout as well as %%stdout%% for -sOutputFile=
* Wed Aug 28 2019 Dr. Werner Fink <werner@suse.de>
- Fix spelling of coreutils
* Mon Aug 26 2019 Jan Engelhardt <jengelh@inai.de>
- Fix grammar of description.
* Tue Aug 20 2019 Dr. Werner Fink <werner@suse.de>
- Update upstream to https://github.com/bitstreamout/ghostscriptwrap
* Wed Aug 14 2019 Dr. Werner Fink <werner@suse.de>
- Bind the temporary FIFO below home in container
* Tue Aug 13 2019 Dr. Werner Fink <werner@suse.de>
- Initial package gswrap to wrap ghostscript within a container
